@@ -49,7 +49,6 @@ DBISTATE_DECLARE;
 /* These prototypes are for dbdimp.c funcs used in the XS file          */
 /* These names are #defined to driver specific names in dbdimp.h        */
 
-#define CAS_ER_PARAM_NAME                   -10011
 
 /* CUBRID types */
 
@@ -59,9 +58,6 @@ DBISTATE_DECLARE;
 #define CUBRID_ER_WRITE_FILE                -30003
 #define CUBRID_ER_READ_FILE                 -30004
 #define CUBRID_ER_NOT_LOB_TYPE              -30005
-#define CUBRID_ER_INVALID_PARAM             -30006
-#define CUBRID_ER_ROW_INDEX_EXCEEDED        -30007
-#define CUBRID_ER_EXPORT_NULL_LOB_INVALID   -30008 
 #define CUBRID_ER_END                       -31000
 
 /* end of cubrid.h */
