@@ -41,7 +41,7 @@ use strict;
 
     require_version DBI 1.61;
 
-    $VERSION = '8.4.4.0002';
+    $VERSION = '9.0.0.0001';
 
     bootstrap DBD::cubrid $VERSION;
 
@@ -317,9 +317,6 @@ use strict;
         for my $row (@$desc) {
 
             my $type = $row->{type};
-            if (!defined($type)) {
-                $type = "NULL";
-            }
 
             my $info = {
                 TABLE_CAT               => $catalog,
@@ -454,9 +451,6 @@ use strict;
                     $info->{COLUMN_SIZE} = 1073741823;
                 }
             }
-            elsif ($type =~ /^NULL$/) {
-                $info->{DATA_TYPE} = SQL_UNKNOWN_TYPE;
-            }
             else {
                 $info->{DATA_TYPE} = SQL_VARCHAR;
             }
@@ -1127,8 +1121,7 @@ Allows the user to bind a value and/or a data type to a placeholder. The value o
 is a number of using the '?' style placeholder. Generally, you can bind params without specifying
 the data type. CUBRID will match it automatically. That means, you don't use C<$bind_type> for
 most data types in CUBRID. But it won't work well with some special data types, such as BLOB and
-CLOB. The following are data types supported by CUBRID.In CUBRID shard envrioment, the $bind_type 
-must be included in the bind_param function.
+CLOB. The following are data types supported by CUBRID.
 
     -----------------------------------------
     | CUBRID        | sql_types             |
@@ -1171,32 +1164,6 @@ Examples of use:
     $sth->bind_param (2, "HELLO WORLD", DBI::SQL_CLOB);
     $sth->execute;
 
-=head3 B<bind_param_array>
-
-Binds an array of values to a placeholder.
-
-    $sth->bind_param_array ($index, $array_ref_or_value);
-    $sth->bind_param_array ($index, $array_ref_or_value, $bind_type);
-    $sth->bind_param_array ($index, $array_ref_or_value, \%attr);
-    $sth->execute_array( \%attrs, @array_of_arrays);
-    
-Examples of use:
-    
-    #!perl -w
-    use DBI;
-    use Test::More;
-    use strict;
- 
-    my $dsn="dbi:cubrid:database=demodb;host=localhost;port=33000";
-    my $dbh=DBI->connect($dsn, "dba", "");
- 
-    $dbh->do("DROP TABLE IF EXISTS test_cubrid");
-    $dbh->do("CREATE TABLE test_cubrid (id VARCHAR)");
- 
-    my $sth = $dbh->prepare ("INSERT INTO test_cubrid VALUES (?)");
-    ok $sth->bind_param_array (1, ['aaa', 'bbb']);
-    ok $sth->execute_array( { ArrayTupleStatus => \my @tuple_status } );
-    
 =head3 B<execute>
 
     $rv = $sth->execute;
@@ -1206,31 +1173,6 @@ Executes a previously prepared statement. In addition to UPDATE, DELETE, INSERT
 statements, for which it returns always the number of affected rows and to SELECT
 statements, it returns the number of rows thart will be returned by the query.
 
-=head3 B<execute_array>  
-  
-Execute a prepared statement once for each item in a passed-in hashref, or items that were 
-previously bound via the "bind_param_array" method. See the DBI documentation for more details.
-
-    $sth->execute_array()
-    $sth->execute_array(\%attr)
-    $sth->execute_array(\%attr, @bind_values)
-   
-Examples of use:
-    
-    use strict;
-    use DBI qw(:sql_types);
-    use Data::Dumper;
-     
-    my $dsn="dbi:cubrid:database=demodb;host=localhost;port=33000";
-    my $dbh=DBI->connect($dsn, "dba", "");
-		 
-    $dbh->do("DROP TABLE IF EXISTS test_cubrid");
-    $dbh->do("CREATE TABLE test_cubrid (id INT)");
-    
-    my $sth = $dbh->prepare ("INSERT INTO test_cubrid VALUES (?)");
-    my @tuple_status;
-    ok $sth->execute_array( { ArrayTupleStatus => \my @tuple_status } , [2,3,4,9]);
-        
 =head3 B<fetchrow_arrayref>
 
     $ary_ref = $sth->fetchrow_arrayref;
